diff --git a/src/Microsoft.TestPlatform.Client/DesignMode/DesignModeClient.cs b/src/Microsoft.TestPlatform.Client/DesignMode/DesignModeClient.cs
index d49af32336..6b16b27a55 100644
--- a/src/Microsoft.TestPlatform.Client/DesignMode/DesignModeClient.cs
+++ b/src/Microsoft.TestPlatform.Client/DesignMode/DesignModeClient.cs
@@ -9,7 +9,7 @@ namespace Microsoft.VisualStudio.TestPlatform.Client.DesignMode
using System.Net;
using System.Threading;
using System.Threading.Tasks;
- using Microsoft.VisualStudio.TestPlatform.Client.MultiTestRunFinalization;
+ using Microsoft.VisualStudio.TestPlatform.Client.TestRunAttachmentsProcessing;
using Microsoft.VisualStudio.TestPlatform.Client.RequestHelper;
using Microsoft.VisualStudio.TestPlatform.Common.Logging;
using Microsoft.VisualStudio.TestPlatform.Common.Utilities;
@@ -199,11 +199,11 @@ private void ProcessRequests(ITestRequestManager testRequestManager)
break;
}
- case MessageType.MultiTestRunFinalizationStart:
+ case MessageType.TestRunAttachmentsProcessingStart:
{
- var multiTestRunFinalizationPayload =
- this.communicationManager.DeserializePayload(message);
- this.StartMultiTestRunFinalization(multiTestRunFinalizationPayload, testRequestManager);
+ var testRunAttachmentsProcessingPayload =
+ this.communicationManager.DeserializePayload(message);
+ this.StartTestRunAttachmentsProcessing(testRunAttachmentsProcessingPayload, testRequestManager);
break;
}
@@ -225,9 +225,9 @@ private void ProcessRequests(ITestRequestManager testRequestManager)
break;
}
- case MessageType.MultiTestRunFinalizationCancel:
+ case MessageType.TestRunAttachmentsProcessingCancel:
{
- testRequestManager.CancelMultiTestRunFinalization();
+ testRequestManager.CancelTestRunAttachmentsProcessing();
break;
}
@@ -472,29 +472,29 @@ private void StartDiscovery(DiscoveryRequestPayload discoveryRequestPayload, ITe
});
}
- private void StartMultiTestRunFinalization(MultiTestRunFinalizationPayload finalizationPayload, ITestRequestManager testRequestManager)
+ private void StartTestRunAttachmentsProcessing(TestRunAttachmentsProcessingPayload attachmentsProcessingPayload, ITestRequestManager testRequestManager)
{
Task.Run(
delegate
{
try
{
- testRequestManager.FinalizeMultiTestRun(finalizationPayload, new MultiTestRunFinalizationEventsHandler(this.communicationManager), this.protocolConfig);
+ testRequestManager.ProcessTestRunAttachments(attachmentsProcessingPayload, new TestRunAttachmentsProcessingEventsHandler(this.communicationManager), this.protocolConfig);
}
catch (Exception ex)
{
- EqtTrace.Error("DesignModeClient: Exception in StartMultiTestRunFinalization: " + ex);
+ EqtTrace.Error("DesignModeClient: Exception in StartTestRunAttachmentsProcessing: " + ex);
var testMessagePayload = new TestMessagePayload { MessageLevel = TestMessageLevel.Error, Message = ex.ToString() };
this.communicationManager.SendMessage(MessageType.TestMessage, testMessagePayload);
- var payload = new MultiTestRunFinalizationCompletePayload()
+ var payload = new TestRunAttachmentsProcessingCompletePayload()
{
Attachments = null
};
// Send run complete to translation layer
- this.communicationManager.SendMessage(MessageType.MultiTestRunFinalizationComplete, payload);
+ this.communicationManager.SendMessage(MessageType.TestRunAttachmentsProcessingComplete, payload);
}
});
}
diff --git a/src/Microsoft.TestPlatform.Common/Telemetry/TelemetryDataConstants.cs b/src/Microsoft.TestPlatform.Common/Telemetry/TelemetryDataConstants.cs
index 671350a63e..be35c610c2 100644
--- a/src/Microsoft.TestPlatform.Common/Telemetry/TelemetryDataConstants.cs
+++ b/src/Microsoft.TestPlatform.Common/Telemetry/TelemetryDataConstants.cs
@@ -90,19 +90,19 @@ public static class TelemetryDataConstants
public static string NumberOfAdapterUsedToDiscoverTests = "VS.TestDiscovery.AdaptersUsedCount";
- // *********************Finalization****************************
- public static string NumberOfAttachmentsSentForFinalization = "VS.TestFinalization.InitialAttachmentsCount";
+ // *********************Attachments Processing****************************
+ public static string NumberOfAttachmentsSentForProcessing = "VS.AttachmentsProcessing.InitialAttachmentsCount";
- public static string NumberOfAttachmentsAfterFinalization = "VS.TestFinalization.FinalAttachmentsCount";
+ public static string NumberOfAttachmentsAfterProcessing = "VS.AttachmentsProcessing.FinalAttachmentsCount";
- public static string TimeTakenInSecForFinalization = "VS.TestFinalization.TotalTimeTakenInSec";
- public static string FinalizationState = "VS.TestFinalization.FinalizationState";
+ public static string TimeTakenInSecForAttachmentsProcessing = "VS.AttachmentsProcessing.TotalTimeTakenInSec";
+ public static string AttachmentsProcessingState = "VS.AttachmentsProcessing.State";
// **************Events Name **********************************
public static string TestDiscoveryCompleteEvent = "vs/testplatform/testdiscoverysession";
public static string TestExecutionCompleteEvent = "vs/testplatform/testrunsession";
- public static string TestFinalizationCompleteEvent = "vs/testplatform/testfinalizationsession";
+ public static string TestAttachmentsProcessingCompleteEvent = "vs/testplatform/testattachmentsprocessingsession";
}
}
diff --git a/src/Microsoft.TestPlatform.CoreUtilities/Tracing/TestPlatformEventSource.cs b/src/Microsoft.TestPlatform.CoreUtilities/Tracing/TestPlatformEventSource.cs
index cf7a4f5845..74adb6a2af 100644
--- a/src/Microsoft.TestPlatform.CoreUtilities/Tracing/TestPlatformEventSource.cs
+++ b/src/Microsoft.TestPlatform.CoreUtilities/Tracing/TestPlatformEventSource.cs
@@ -239,45 +239,45 @@ public void MetricsDisposeStop()
}
///
- [Event(TestPlatformInstrumentationEvents.MultiTestRunFinalizationRequestStartEventId)]
- public void MultiTestRunFinalizationRequestStart()
+ [Event(TestPlatformInstrumentationEvents.TestRunAttachmentsProcessingRequestStartEventId)]
+ public void TestRunAttachmentsProcessingRequestStart()
{
- this.WriteEvent(TestPlatformInstrumentationEvents.MultiTestRunFinalizationRequestStartEventId);
+ this.WriteEvent(TestPlatformInstrumentationEvents.TestRunAttachmentsProcessingRequestStartEventId);
}
///
- [Event(TestPlatformInstrumentationEvents.MultiTestRunFinalizationRequestStopEventId)]
- public void MultiTestRunFinalizationRequestStop()
+ [Event(TestPlatformInstrumentationEvents.TestRunAttachmentsProcessingRequestStopEventId)]
+ public void TestRunAttachmentsProcessingRequestStop()
{
- this.WriteEvent(TestPlatformInstrumentationEvents.MultiTestRunFinalizationRequestStopEventId);
+ this.WriteEvent(TestPlatformInstrumentationEvents.TestRunAttachmentsProcessingRequestStopEventId);
}
///
- [Event(TestPlatformInstrumentationEvents.MultiTestRunFinalizationStartEventId)]
- public void MultiTestRunFinalizationStart(long numberOfAttachments)
+ [Event(TestPlatformInstrumentationEvents.TestRunAttachmentsProcessingStartEventId)]
+ public void TestRunAttachmentsProcessingStart(long numberOfAttachments)
{
- this.WriteEvent(TestPlatformInstrumentationEvents.MultiTestRunFinalizationStartEventId, numberOfAttachments);
+ this.WriteEvent(TestPlatformInstrumentationEvents.TestRunAttachmentsProcessingStartEventId, numberOfAttachments);
}
///
- [Event(TestPlatformInstrumentationEvents.MultiTestRunFinalizationStopEventId)]
- public void MultiTestRunFinalizationStop(long numberOfAttachments)
+ [Event(TestPlatformInstrumentationEvents.TestRunAttachmentsProcessingStopEventId)]
+ public void TestRunAttachmentsProcessingStop(long numberOfAttachments)
{
- this.WriteEvent(TestPlatformInstrumentationEvents.MultiTestRunFinalizationStopEventId, numberOfAttachments);
+ this.WriteEvent(TestPlatformInstrumentationEvents.TestRunAttachmentsProcessingStopEventId, numberOfAttachments);
}
///
- [Event(TestPlatformInstrumentationEvents.TranslationLayerMultiTestRunFinalizationStartEventId)]
- public void TranslationLayerMultiTestRunFinalizationStart()
+ [Event(TestPlatformInstrumentationEvents.TranslationLayerTestRunAttachmentsProcessingStartEventId)]
+ public void TranslationLayerTestRunAttachmentsProcessingStart()
{
- this.WriteEvent(TestPlatformInstrumentationEvents.TranslationLayerMultiTestRunFinalizationStartEventId);
+ this.WriteEvent(TestPlatformInstrumentationEvents.TranslationLayerTestRunAttachmentsProcessingStartEventId);
}
///
- [Event(TestPlatformInstrumentationEvents.TranslationLayerMultiTestRunFinalizationStopEventId)]
- public void TranslationLayerMultiTestRunFinalizationStop()
+ [Event(TestPlatformInstrumentationEvents.TranslationLayerTestRunAttachmentsProcessingStopEventId)]
+ public void TranslationLayerTestRunAttachmentsProcessingStop()
{
- this.WriteEvent(TestPlatformInstrumentationEvents.TranslationLayerMultiTestRunFinalizationStopEventId);
+ this.WriteEvent(TestPlatformInstrumentationEvents.TranslationLayerTestRunAttachmentsProcessingStopEventId);
}
}
}
diff --git a/src/Microsoft.TestPlatform.CrossPlatEngine/Client/Parallel/ParallelProxyExecutionManager.cs b/src/Microsoft.TestPlatform.CrossPlatEngine/Client/Parallel/ParallelProxyExecutionManager.cs
index 86df14a387..d5cc0cecb4 100644
--- a/src/Microsoft.TestPlatform.CrossPlatEngine/Client/Parallel/ParallelProxyExecutionManager.cs
+++ b/src/Microsoft.TestPlatform.CrossPlatEngine/Client/Parallel/ParallelProxyExecutionManager.cs
@@ -16,7 +16,7 @@ namespace Microsoft.VisualStudio.TestPlatform.CrossPlatEngine.Client.Parallel
using Microsoft.VisualStudio.TestPlatform.CommunicationUtilities.ObjectModel;
using Microsoft.VisualStudio.TestPlatform.CoreUtilities.Tracing;
using Microsoft.VisualStudio.TestPlatform.CrossPlatEngine.DataCollection;
- using Microsoft.VisualStudio.TestPlatform.CrossPlatEngine.MultiTestRunFinalization;
+ using Microsoft.VisualStudio.TestPlatform.CrossPlatEngine.TestRunAttachmentsProcessing;
using Microsoft.VisualStudio.TestPlatform.ObjectModel;
using Microsoft.VisualStudio.TestPlatform.ObjectModel.Client;
using Microsoft.VisualStudio.TestPlatform.ObjectModel.Engine;
@@ -262,7 +262,7 @@ private ParallelRunEventsHandler GetEventsHandler(IProxyExecutionManager concurr
var concurrentManagerWithDataCollection = concurrentManager as ProxyExecutionManagerWithDataCollection;
// TODO : use TestPluginCache to iterate over all IDataCollectorAttachments
- var finalizationManager = new MultiTestRunFinalizationManager(TestPlatformEventSource.Instance, new CodeCoverageDataAttachmentsHandler());
+ var attachmentsProcessingManager = new TestRunAttachmentsProcessingManager(TestPlatformEventSource.Instance, new CodeCoverageDataAttachmentsHandler());
return new ParallelDataCollectionEventsHandler(
this.requestData,
@@ -270,7 +270,7 @@ private ParallelRunEventsHandler GetEventsHandler(IProxyExecutionManager concurr
this.currentRunEventsHandler,
this,
this.currentRunDataAggregator,
- finalizationManager,
+ attachmentsProcessingManager,
concurrentManagerWithDataCollection.CancellationToken);
}
diff --git a/src/Microsoft.TestPlatform.CrossPlatEngine/DataCollection/ParallelDataCollectionEventsHandler.cs b/src/Microsoft.TestPlatform.CrossPlatEngine/DataCollection/ParallelDataCollectionEventsHandler.cs
index f6c2ea0829..a50d5fe6ff 100644
--- a/src/Microsoft.TestPlatform.CrossPlatEngine/DataCollection/ParallelDataCollectionEventsHandler.cs
+++ b/src/Microsoft.TestPlatform.CrossPlatEngine/DataCollection/ParallelDataCollectionEventsHandler.cs
@@ -16,7 +16,7 @@ namespace Microsoft.VisualStudio.TestPlatform.CrossPlatEngine.DataCollection
internal class ParallelDataCollectionEventsHandler : ParallelRunEventsHandler
{
private readonly ParallelRunDataAggregator runDataAggregator;
- private readonly IMultiTestRunFinalizationManager finalizationManager;
+ private readonly ITestRunAttachmentsProcessingManager attachmentsProcessingManager;
private readonly CancellationToken cancellationToken;
public ParallelDataCollectionEventsHandler(IRequestData requestData,
@@ -24,11 +24,11 @@ public ParallelDataCollectionEventsHandler(IRequestData requestData,
ITestRunEventsHandler actualRunEventsHandler,
IParallelProxyExecutionManager parallelProxyExecutionManager,
ParallelRunDataAggregator runDataAggregator,
- IMultiTestRunFinalizationManager finalizationManager,
+ ITestRunAttachmentsProcessingManager attachmentsProcessingManager,
CancellationToken cancellationToken) :
this(requestData, proxyExecutionManager, actualRunEventsHandler, parallelProxyExecutionManager, runDataAggregator, JsonDataSerializer.Instance)
{
- this.finalizationManager = finalizationManager;
+ this.attachmentsProcessingManager = attachmentsProcessingManager;
this.cancellationToken = cancellationToken;
}
@@ -56,7 +56,7 @@ public override void HandleTestRunComplete(
if (parallelRunComplete)
{
- runDataAggregator.RunContextAttachments = finalizationManager.FinalizeMultiTestRunAsync(requestData, runDataAggregator.RunContextAttachments, cancellationToken).Result ?? runDataAggregator.RunContextAttachments;
+ runDataAggregator.RunContextAttachments = attachmentsProcessingManager.ProcessTestRunAttachmentsAsync(requestData, runDataAggregator.RunContextAttachments, cancellationToken).Result ?? runDataAggregator.RunContextAttachments;
var completedArgs = new TestRunCompleteEventArgs(this.runDataAggregator.GetAggregatedRunStats(),
this.runDataAggregator.IsCanceled,
diff --git a/src/Microsoft.TestPlatform.ObjectModel/Client/Events/MultiTestRunFinalizationProgressEventArgs.cs b/src/Microsoft.TestPlatform.ObjectModel/Client/Events/TestRunAttachmentsProcessingProgressEventArgs.cs
similarity index 87%
rename from src/Microsoft.TestPlatform.ObjectModel/Client/Events/MultiTestRunFinalizationProgressEventArgs.cs
rename to src/Microsoft.TestPlatform.ObjectModel/Client/Events/TestRunAttachmentsProcessingProgressEventArgs.cs
index 9710add944..8218336e5b 100644
--- a/src/Microsoft.TestPlatform.ObjectModel/Client/Events/MultiTestRunFinalizationProgressEventArgs.cs
+++ b/src/Microsoft.TestPlatform.ObjectModel/Client/Events/TestRunAttachmentsProcessingProgressEventArgs.cs
@@ -8,7 +8,7 @@ namespace Microsoft.VisualStudio.TestPlatform.ObjectModel.Client
using System.Runtime.Serialization;
[DataContract]
- public class MultiTestRunFinalizationProgressEventArgs : EventArgs
+ public class TestRunAttachmentsProcessingProgressEventArgs : EventArgs
{
///
/// Default constructor.
@@ -17,7 +17,7 @@ public class MultiTestRunFinalizationProgressEventArgs : EventArgs
/// Specifies current processor Uris.
/// Specifies current processor progress.
/// Specifies the overall number of processors.
- public MultiTestRunFinalizationProgressEventArgs(long currentAttachmentProcessorIndex, ICollection currentAttachmentProcessorUris, long currentAttachmentProcessorProgress, long attachmentProcessorsCount)
+ public TestRunAttachmentsProcessingProgressEventArgs(long currentAttachmentProcessorIndex, ICollection currentAttachmentProcessorUris, long currentAttachmentProcessorProgress, long attachmentProcessorsCount)
{
CurrentAttachmentProcessorIndex = currentAttachmentProcessorIndex;
CurrentAttachmentProcessorUris = currentAttachmentProcessorUris;
diff --git a/src/Microsoft.TestPlatform.ObjectModel/Client/Interfaces/IMultiTestRunFinalizationEventsHandler.cs b/src/Microsoft.TestPlatform.ObjectModel/Client/Interfaces/IMultiTestRunFinalizationEventsHandler.cs
deleted file mode 100644
index 3983bd571e..0000000000
--- a/src/Microsoft.TestPlatform.ObjectModel/Client/Interfaces/IMultiTestRunFinalizationEventsHandler.cs
+++ /dev/null
@@ -1,32 +0,0 @@
-// Copyright (c) Microsoft Corporation. All rights reserved.
-// Licensed under the MIT license. See LICENSE file in the project root for full license information.
-
-using System.Collections.Generic;
-
-namespace Microsoft.VisualStudio.TestPlatform.ObjectModel.Client
-{
- ///
- /// Interface contract for handling multi test run finalization events
- ///
- public interface IMultiTestRunFinalizationEventsHandler : ITestMessageEventHandler
- {
- ///
- /// Dispatch MultiTestRunFinalizationComplete event to listeners.
- ///
- /// Finalization Complete event args.
- /// Last set of processed attachment sets.
- void HandleMultiTestRunFinalizationComplete(MultiTestRunFinalizationCompleteEventArgs finalizationCompleteEventArgs, IEnumerable lastChunk);
-
- ///
- /// Dispatch ProcessedAttachmentsChunk event to listeners.
- ///
- /// Processed attachment sets.
- void HandleProcessedAttachmentsChunk(IEnumerable attachments);
-
- ///
- /// Dispatch MultiTestRunFinalizationProgress event to listeners.
- ///
- /// Finalization Progress event args.
- void HandleMultiTestRunFinalizationProgress(MultiTestRunFinalizationProgressEventArgs finalizationProgressEventArgs);
- }
-}
\ No newline at end of file
diff --git a/src/Microsoft.TestPlatform.ObjectModel/Client/Interfaces/ITestRunAttachmentsProcessingEventsHandler.cs b/src/Microsoft.TestPlatform.ObjectModel/Client/Interfaces/ITestRunAttachmentsProcessingEventsHandler.cs
new file mode 100644
index 0000000000..f6235a92e9
--- /dev/null
+++ b/src/Microsoft.TestPlatform.ObjectModel/Client/Interfaces/ITestRunAttachmentsProcessingEventsHandler.cs
@@ -0,0 +1,32 @@
+// Copyright (c) Microsoft Corporation. All rights reserved.
+// Licensed under the MIT license. See LICENSE file in the project root for full license information.
+
+using System.Collections.Generic;
+
+namespace Microsoft.VisualStudio.TestPlatform.ObjectModel.Client
+{
+ ///
+ /// Interface contract for handling test run attachments processing events
+ ///
+ public interface ITestRunAttachmentsProcessingEventsHandler : ITestMessageEventHandler
+ {
+ ///
+ /// Dispatch TestRunAttachmentsProcessingComplete event to listeners.
+ ///
+ /// AttachmentsProcessing Complete event args.
+ /// Last set of processed attachment sets.
+ void HandleTestRunAttachmentsProcessingComplete(TestRunAttachmentsProcessingCompleteEventArgs attachmentsProcessingCompleteEventArgs, IEnumerable lastChunk);
+
+ ///
+ /// Dispatch ProcessedAttachmentsChunk event to listeners.
+ ///
+ /// Processed attachment sets.
+ void HandleProcessedAttachmentsChunk(IEnumerable attachments);
+
+ ///
+ /// Dispatch TestRunAttachmentsProcessingProgress event to listeners.
+ ///
+ /// AttachmentsProcessing Progress event args.
+ void HandleTestRunAttachmentsProcessingProgress(TestRunAttachmentsProcessingProgressEventArgs AttachmentsProcessingProgressEventArgs);
+ }
+}
\ No newline at end of file
diff --git a/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Interfaces/ITranslationLayerRequestSenderAsync.cs b/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Interfaces/ITranslationLayerRequestSenderAsync.cs
index 19ef32c915..23166126d7 100644
--- a/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Interfaces/ITranslationLayerRequestSenderAsync.cs
+++ b/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Interfaces/ITranslationLayerRequestSenderAsync.cs
@@ -53,8 +53,8 @@ internal interface ITranslationLayerRequestSenderAsync : IDisposable
///
/// Collection of attachments
/// Enables metrics collection
- /// Events handler
+ /// Events handler
/// Cancellation token
- Task FinalizeMultiTestRunAsync(IEnumerable attachments, bool collectMetrics, IMultiTestRunFinalizationEventsHandler multiTestRunFinalizationCompleteEventsHandler, CancellationToken cancellationToken);
+ Task ProcessTestRunAttachmentsAsync(IEnumerable attachments, bool collectMetrics, ITestRunAttachmentsProcessingEventsHandler testRunAttachmentsProcessingCompleteEventsHandler, CancellationToken cancellationToken);
}
}
diff --git a/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Interfaces/IVsTestConsoleWrapperAsync.cs b/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Interfaces/IVsTestConsoleWrapperAsync.cs
index 14b32ab427..9c5af36304 100644
--- a/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Interfaces/IVsTestConsoleWrapperAsync.cs
+++ b/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Interfaces/IVsTestConsoleWrapperAsync.cs
@@ -100,7 +100,7 @@ public interface IVsTestConsoleWrapperAsync
/// Enables metrics collection (used for telemetry)
/// EventHandler to receive session complete event
/// Cancellation token
- Task FinalizeMultiTestRunAsync(IEnumerable attachments, bool multiTestRunCompleted, bool collectMetrics, IMultiTestRunFinalizationEventsHandler eventsHandler, CancellationToken cancellationToken);
+ Task ProcessTestRunAttachmentsAsync(IEnumerable attachments, bool multiTestRunCompleted, bool collectMetrics, ITestRunAttachmentsProcessingEventsHandler eventsHandler, CancellationToken cancellationToken);
///
/// See .
diff --git a/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/Resources.resx b/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/Resources.resx
index ff17cc093a..eb053d0a74 100644
--- a/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/Resources.resx
+++ b/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/Resources.resx
@@ -117,8 +117,8 @@
System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
- The active Multi Test Runs Finalization was aborted.
+
+ The active Test Run Attachments Processing was aborted.
The active Tests Discovery was aborted.
diff --git a/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/xlf/Resources.cs.xlf b/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/xlf/Resources.cs.xlf
index 819e22e1d4..378546e5aa 100644
--- a/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/xlf/Resources.cs.xlf
+++ b/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/xlf/Resources.cs.xlf
@@ -61,9 +61,9 @@
Soubor {0} neexistuje.
-
-
- The active Multi Test Runs Finalization was aborted.
+
+
+ The active Test Run Attachments Processing was aborted.
diff --git a/src/Microsoft.TestPlatform.Client/MultiTestRunFinalization/MultiTestRunFinalizationEventsHandler.cs b/src/Microsoft.TestPlatform.Client/AttachmentsProcessing/TestRunAttachmentsProcessingEventsHandler.cs
similarity index 55%
rename from src/Microsoft.TestPlatform.Client/MultiTestRunFinalization/MultiTestRunFinalizationEventsHandler.cs
rename to src/Microsoft.TestPlatform.Client/AttachmentsProcessing/TestRunAttachmentsProcessingEventsHandler.cs
index f0359712de..3a5674db16 100644
--- a/src/Microsoft.TestPlatform.Client/MultiTestRunFinalization/MultiTestRunFinalizationEventsHandler.cs
+++ b/src/Microsoft.TestPlatform.Client/AttachmentsProcessing/TestRunAttachmentsProcessingEventsHandler.cs
@@ -1,7 +1,7 @@
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT license. See LICENSE file in the project root for full license information.
-namespace Microsoft.VisualStudio.TestPlatform.Client.MultiTestRunFinalization
+namespace Microsoft.VisualStudio.TestPlatform.Client.TestRunAttachmentsProcessing
{
using Microsoft.VisualStudio.TestPlatform.CommunicationUtilities.Interfaces;
using Microsoft.VisualStudio.TestPlatform.CommunicationUtilities.ObjectModel;
@@ -11,47 +11,48 @@ namespace Microsoft.VisualStudio.TestPlatform.Client.MultiTestRunFinalization
using System.Collections.Generic;
///
/// The multi test finalization events handler.
///
- public class MultiTestRunFinalizationEventsHandler : IMultiTestRunFinalizationEventsHandler
+ ///
+ public class TestRunAttachmentsProcessingEventsHandler : ITestRunAttachmentsProcessingEventsHandler
{
private readonly ICommunicationManager communicationManager;
///
- /// Initializes a new instance of the class.
+ /// Initializes a new instance of the class.
///
/// The communication manager.
- public MultiTestRunFinalizationEventsHandler(ICommunicationManager communicationManager)
+ public TestRunAttachmentsProcessingEventsHandler(ICommunicationManager communicationManager)
{
this.communicationManager = communicationManager;
}
///
- public void HandleMultiTestRunFinalizationComplete(MultiTestRunFinalizationCompleteEventArgs finalizationCompleteEventArgs, IEnumerable lastChunk)
+ public void HandleTestRunAttachmentsProcessingComplete(TestRunAttachmentsProcessingCompleteEventArgs attachmentsProcessingCompleteEventArgs, IEnumerable lastChunk)
{
if (EqtTrace.IsInfoEnabled)
{
- EqtTrace.Info("Multi test run finalization completed.");
+ EqtTrace.Info("Test run attachments processing completed.");
}
- var payload = new MultiTestRunFinalizationCompletePayload()
+ var payload = new TestRunAttachmentsProcessingCompletePayload()
{
- FinalizationCompleteEventArgs = finalizationCompleteEventArgs,
+ AttachmentsProcessingCompleteEventArgs = attachmentsProcessingCompleteEventArgs,
Attachments = lastChunk
};
- this.communicationManager.SendMessage(MessageType.MultiTestRunFinalizationComplete, payload);
+ this.communicationManager.SendMessage(MessageType.TestRunAttachmentsProcessingComplete, payload);
}
///
- public void HandleMultiTestRunFinalizationProgress(MultiTestRunFinalizationProgressEventArgs finalizationProgressEventArgs)
+ public void HandleTestRunAttachmentsProcessingProgress(TestRunAttachmentsProcessingProgressEventArgs AttachmentsProcessingProgressEventArgs)
{
- var payload = new MultiTestRunFinalizationProgressPayload()
+ var payload = new TestRunAttachmentsProcessingProgressPayload()
{
- FinalizationProgressEventArgs = finalizationProgressEventArgs,
+ AttachmentsProcessingProgressEventArgs = AttachmentsProcessingProgressEventArgs,
};
- this.communicationManager.SendMessage(MessageType.MultiTestRunFinalizationProgress, payload);
+ this.communicationManager.SendMessage(MessageType.TestRunAttachmentsProcessingProgress, payload);
}
///
@@ -11,47 +11,48 @@ namespace Microsoft.VisualStudio.TestPlatform.Client.MultiTestRunFinalization
using System.Collections.Generic;
///
- /// The multi test finalization events handler.
+ /// The test run attachments processing events handler.
///
diff --git a/src/Microsoft.TestPlatform.Client/RequestHelper/ITestRequestManager.cs b/src/Microsoft.TestPlatform.Client/RequestHelper/ITestRequestManager.cs
index eb18c4fa0b..0a0e68e301 100644
--- a/src/Microsoft.TestPlatform.Client/RequestHelper/ITestRequestManager.cs
+++ b/src/Microsoft.TestPlatform.Client/RequestHelper/ITestRequestManager.cs
@@ -45,11 +45,11 @@ public interface ITestRequestManager : IDisposable
void RunTests(TestRunRequestPayload testRunRequestPayLoad, ITestHostLauncher customTestHostLauncher, ITestRunEventsRegistrar testRunEventsRegistrar, ProtocolConfig protocolConfig);
///
/// Finalize multi test run
///
- /// Multi test run finalization payload
- /// Multi test run finalization events handler
- void FinalizeMultiTestRun(MultiTestRunFinalizationPayload multiTestRunFinalizationPayload, IMultiTestRunFinalizationEventsHandler multiTestRunFinalizationEventsHandler, ProtocolConfig protocolConfig);
+ /// Test run attachments processing payload
+ /// Test run attachments processing events handler
+ void ProcessTestRunAttachments(TestRunAttachmentsProcessingPayload testRunAttachmentsProcessingPayload, ITestRunAttachmentsProcessingEventsHandler testRunAttachmentsProcessingEventsHandler, ProtocolConfig protocolConfig);
///
/// Cancel the current TestRun request
@@ -67,8 +67,8 @@ public interface ITestRequestManager : IDisposable
void CancelDiscovery();
///
/// Cancels the current multi test run finalization request
///
- void CancelMultiTestRunFinalization();
+ void CancelTestRunAttachmentsProcessing();
}
}
@@ -45,11 +45,11 @@ public interface ITestRequestManager : IDisposable
void RunTests(TestRunRequestPayload testRunRequestPayLoad, ITestHostLauncher customTestHostLauncher, ITestRunEventsRegistrar testRunEventsRegistrar, ProtocolConfig protocolConfig);
///
- /// Finalize multi test run
+ /// Processes test run attachments
///
@@ -67,8 +67,8 @@ public interface ITestRequestManager : IDisposable
void CancelDiscovery();
///
- /// Cancels the current multi test run finalization request
+ /// Cancels the current test run attachments processing request
///
diff --git a/src/Microsoft.TestPlatform.Common/Interfaces/Engine/IMultiTestRunFinalizationManager.cs b/src/Microsoft.TestPlatform.Common/Interfaces/Engine/ITestRunAttachmentsProcessingManager.cs
similarity index 59%
rename from src/Microsoft.TestPlatform.Common/Interfaces/Engine/IMultiTestRunFinalizationManager.cs
rename to src/Microsoft.TestPlatform.Common/Interfaces/Engine/ITestRunAttachmentsProcessingManager.cs
index d13ea35f71..d6b88d89c8 100644
--- a/src/Microsoft.TestPlatform.Common/Interfaces/Engine/IMultiTestRunFinalizationManager.cs
+++ b/src/Microsoft.TestPlatform.Common/Interfaces/Engine/ITestRunAttachmentsProcessingManager.cs
@@ -10,24 +10,24 @@
namespace Microsoft.VisualStudio.TestPlatform.ObjectModel.Engine
{
///
/// Orchestrates multi test run finalization operations.
///
- internal interface IMultiTestRunFinalizationManager
+ internal interface ITestRunAttachmentsProcessingManager
{
///
- /// Finalizes multi test run and provides results through handler
+ /// Processes attachments and provides results through handler
///
/// Collection of attachments
/// EventHandler for handling multi test run finalization event
/// Cancellation token
- Task FinalizeMultiTestRunAsync(IRequestData requestData, IEnumerable attachments, IMultiTestRunFinalizationEventsHandler eventHandler, CancellationToken cancellationToken);
+ Task ProcessTestRunAttachmentsAsync(IRequestData requestData, IEnumerable attachments, ITestRunAttachmentsProcessingEventsHandler eventHandler, CancellationToken cancellationToken);
///
- /// Finalizes multi test run
+ /// Processes attachments
///
/// Collection of attachments
/// Cancellation token
/// Collection of attachments.
- Task> FinalizeMultiTestRunAsync(IRequestData requestData, IEnumerable attachments, CancellationToken cancellationToken);
+ Task> ProcessTestRunAttachmentsAsync(IRequestData requestData, IEnumerable attachments, CancellationToken cancellationToken);
}
}
@@ -10,24 +10,24 @@
{
///
- /// Orchestrates multi test run finalization operations.
+ /// Orchestrates test run attachments processing operations.
///
@@ -10,24 +10,24 @@
///
/// Collection of attachments
- /// EventHandler for handling multi test run finalization event
+ /// EventHandler for handling test run attachments processing event
/// Cancellation token
diff --git a/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/MessageType.cs b/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/MessageType.cs
index 802c8e5c87..76cfeec873 100644
--- a/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/MessageType.cs
+++ b/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/MessageType.cs
@@ -124,24 +124,24 @@ public static class MessageType
public const string CustomTestHostLaunchCallback = "TestExecution.CustomTestHostLaunchCallback";
///
/// Multi test run finalization
///
- public const string MultiTestRunFinalizationStart = "MultiTestRunFinalization.Start";
+ public const string TestRunAttachmentsProcessingStart = "TestRunAttachmentsProcessing.Start";
///
/// Multi test run finalization callback
///
- public const string MultiTestRunFinalizationComplete = "MultiTestRunFinalization.Complete";
+ public const string TestRunAttachmentsProcessingComplete = "TestRunAttachmentsProcessing.Complete";
///
/// Multi test run finalization progress
///
- public const string MultiTestRunFinalizationProgress = "MultiTestRunFinalization.Progress";
+ public const string TestRunAttachmentsProcessingProgress = "TestRunAttachmentsProcessing.Progress";
///
/// Cancel multi test run finalization
///
- public const string MultiTestRunFinalizationCancel = "MultiTestRunFinalization.Cancel";
+ public const string TestRunAttachmentsProcessingCancel = "TestRunAttachmentsProcessing.Cancel";
///
/// Extensions Initialization
@@ -124,24 +124,24 @@ public static class MessageType
public const string CustomTestHostLaunchCallback = "TestExecution.CustomTestHostLaunchCallback";
///
- /// Multi test run finalization
+ /// Test run attachments processing
///
@@ -124,24 +124,24 @@ public static class MessageType
///
- /// Multi test run finalization callback
+ /// Test run attachments processing callback
///
@@ -124,24 +124,24 @@ public static class MessageType
///
- /// Multi test run finalization progress
+ /// Test run attachments processing progress
///
@@ -124,24 +124,24 @@ public static class MessageType
///
- /// Cancel multi test run finalization
+ /// Cancel test run attachments processing
///
diff --git a/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/MultiTestRunFinalizationCompletePayload.cs b/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/TestRunAttachmentsProcessingCompletePayload.cs
similarity index 68%
rename from src/Microsoft.TestPlatform.CommunicationUtilities/Messages/MultiTestRunFinalizationCompletePayload.cs
rename to src/Microsoft.TestPlatform.CommunicationUtilities/Messages/TestRunAttachmentsProcessingCompletePayload.cs
index 4d9ef24169..40ac9c4c8b 100644
--- a/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/MultiTestRunFinalizationCompletePayload.cs
+++ b/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/TestRunAttachmentsProcessingCompletePayload.cs
@@ -9,14 +9,14 @@ namespace Microsoft.VisualStudio.TestPlatform.CommunicationUtilities.ObjectModel
using Microsoft.VisualStudio.TestPlatform.ObjectModel.Client;
///
/// Multi test run finalization complete payload.
///
- public class MultiTestRunFinalizationCompletePayload
+ public class TestRunAttachmentsProcessingCompletePayload
{
///
/// Gets or sets the multi test run finalization complete args.
///
- public MultiTestRunFinalizationCompleteEventArgs FinalizationCompleteEventArgs { get; set; }
+ public TestRunAttachmentsProcessingCompleteEventArgs AttachmentsProcessingCompleteEventArgs { get; set; }
///
/// Gets or sets the attachments.
@@ -9,14 +9,14 @@ namespace Microsoft.VisualStudio.TestPlatform.CommunicationUtilities.ObjectModel
using Microsoft.VisualStudio.TestPlatform.ObjectModel.Client;
///
- /// Multi test run finalization complete payload.
+ /// Test run attachments processing complete payload.
///
@@ -9,14 +9,14 @@ namespace Microsoft.VisualStudio.TestPlatform.CommunicationUtilities.ObjectModel
{
///
- /// Gets or sets the multi test run finalization complete args.
+ /// Gets or sets the test run attachments processing complete args.
///
diff --git a/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/MultiTestRunFinalizationProgressPayload.cs b/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/TestRunAttachmentsProcessingProgressPayload.cs
similarity index 57%
rename from src/Microsoft.TestPlatform.CommunicationUtilities/Messages/MultiTestRunFinalizationProgressPayload.cs
rename to src/Microsoft.TestPlatform.CommunicationUtilities/Messages/TestRunAttachmentsProcessingProgressPayload.cs
index 6190ada03c..80082ae30d 100644
--- a/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/MultiTestRunFinalizationProgressPayload.cs
+++ b/src/Microsoft.TestPlatform.CommunicationUtilities/Messages/TestRunAttachmentsProcessingProgressPayload.cs
@@ -6,13 +6,13 @@ namespace Microsoft.VisualStudio.TestPlatform.CommunicationUtilities.ObjectModel
using Microsoft.VisualStudio.TestPlatform.ObjectModel.Client;
///
/// Multi test run finalization complete payload.
///
- public class MultiTestRunFinalizationProgressPayload
+ public class TestRunAttachmentsProcessingProgressPayload
{
///
/// Gets or sets the multi test run finalization complete args.
///
- public MultiTestRunFinalizationProgressEventArgs FinalizationProgressEventArgs { get; set; }
+ public TestRunAttachmentsProcessingProgressEventArgs AttachmentsProcessingProgressEventArgs { get; set; }
}
}
@@ -6,13 +6,13 @@ namespace Microsoft.VisualStudio.TestPlatform.CommunicationUtilities.ObjectModel
using Microsoft.VisualStudio.TestPlatform.ObjectModel.Client;
///
- /// Multi test run finalization complete payload.
+ /// Test run attachments processing complete payload.
///
@@ -6,13 +6,13 @@ namespace Microsoft.VisualStudio.TestPlatform.CommunicationUtilities.ObjectModel
{
///
- /// Gets or sets the multi test run finalization complete args.
+ /// Gets or sets the test run attachments processing complete args.
///
diff --git a/src/Microsoft.TestPlatform.CoreUtilities/Tracing/Interfaces/ITestPlatformEventSource.cs b/src/Microsoft.TestPlatform.CoreUtilities/Tracing/Interfaces/ITestPlatformEventSource.cs
index 262803cf48..7f88ccbf83 100644
--- a/src/Microsoft.TestPlatform.CoreUtilities/Tracing/Interfaces/ITestPlatformEventSource.cs
+++ b/src/Microsoft.TestPlatform.CoreUtilities/Tracing/Interfaces/ITestPlatformEventSource.cs
@@ -184,39 +184,39 @@ public interface ITestPlatformEventSource
void MetricsDisposeStop();
///
/// The multi test run finalization request start.
///
- void MultiTestRunFinalizationRequestStart();
+ void TestRunAttachmentsProcessingRequestStart();
///
/// The multi test run finalization request stop.
///
- void MultiTestRunFinalizationRequestStop();
+ void TestRunAttachmentsProcessingRequestStop();
///
/// The multi test run finalization start.
///
///
/// The number of attachments.
///
- void MultiTestRunFinalizationStart(long numberOfAttachments);
+ void TestRunAttachmentsProcessingStart(long numberOfAttachments);
///
/// The multi test run finalization stop.
///
///
/// The number of attachments.
///
- void MultiTestRunFinalizationStop(long numberOfAttachments);
+ void TestRunAttachmentsProcessingStop(long numberOfAttachments);
///
/// Mark the start of translation layer multi test run finalization request.
///
- void TranslationLayerMultiTestRunFinalizationStart();
+ void TranslationLayerTestRunAttachmentsProcessingStart();
///
/// Mark the completion of translation layer multi test run finalization request.
///
- void TranslationLayerMultiTestRunFinalizationStop();
+ void TranslationLayerTestRunAttachmentsProcessingStop();
}
}
@@ -184,39 +184,39 @@ public interface ITestPlatformEventSource
void MetricsDisposeStop();
///
- /// The multi test run finalization request start.
+ /// The test run attachments processing request start.
///
@@ -184,39 +184,39 @@ public interface ITestPlatformEventSource
///
- /// The multi test run finalization request stop.
+ /// The test run attachments processing request stop.
///
@@ -184,39 +184,39 @@ public interface ITestPlatformEventSource
///
- /// The multi test run finalization start.
+ /// The test run attachments processing start.
///
///
@@ -184,39 +184,39 @@ public interface ITestPlatformEventSource
///
- /// The multi test run finalization stop.
+ /// The test run attachments processing stop.
///
///
@@ -184,39 +184,39 @@ public interface ITestPlatformEventSource
///
- /// Mark the start of translation layer multi test run finalization request.
+ /// Mark the start of translation layer test run attachments processing request.
///
@@ -184,39 +184,39 @@ public interface ITestPlatformEventSource
///
- /// Mark the completion of translation layer multi test run finalization request.
+ /// Mark the completion of translation layer test run attachments processing request.
///
diff --git a/src/Microsoft.TestPlatform.CoreUtilities/Tracing/TestPlatformInstrumentationEvents.cs b/src/Microsoft.TestPlatform.CoreUtilities/Tracing/TestPlatformInstrumentationEvents.cs
index 2fa7f1e87a..1aa2311048 100644
--- a/src/Microsoft.TestPlatform.CoreUtilities/Tracing/TestPlatformInstrumentationEvents.cs
+++ b/src/Microsoft.TestPlatform.CoreUtilities/Tracing/TestPlatformInstrumentationEvents.cs
@@ -159,33 +159,33 @@ internal class TestPlatformInstrumentationEvents
public const int MetricsDisposeStopEventId = 0x39;
///
/// The session finalization start event id.
///
- public const int MultiTestRunFinalizationStartEventId = 0x40;
+ public const int TestRunAttachmentsProcessingStartEventId = 0x40;
///
/// The session finalization stop event id.
///
- public const int MultiTestRunFinalizationStopEventId = 0x41;
+ public const int TestRunAttachmentsProcessingStopEventId = 0x41;
///
/// The session finalization request start event id.
///
- public const int MultiTestRunFinalizationRequestStartEventId = 0x42;
+ public const int TestRunAttachmentsProcessingRequestStartEventId = 0x42;
///
/// The session finalization request stop event id.
///
- public const int MultiTestRunFinalizationRequestStopEventId = 0x43;
+ public const int TestRunAttachmentsProcessingRequestStopEventId = 0x43;
///
/// Events fired on session finalization start of translation layer.
///
- public const int TranslationLayerMultiTestRunFinalizationStartEventId = 0x44;
+ public const int TranslationLayerTestRunAttachmentsProcessingStartEventId = 0x44;
///
/// Events fired on session finalization complete in translation layer.
///
- public const int TranslationLayerMultiTestRunFinalizationStopEventId = 0x45;
+ public const int TranslationLayerTestRunAttachmentsProcessingStopEventId = 0x45;
}
}
\ No newline at end of file
@@ -159,33 +159,33 @@ internal class TestPlatformInstrumentationEvents
public const int MetricsDisposeStopEventId = 0x39;
///
- /// The session finalization start event id.
+ /// The session attachments processing start event id.
///
@@ -159,33 +159,33 @@ internal class TestPlatformInstrumentationEvents
///
- /// The session finalization stop event id.
+ /// The session attachments processing stop event id.
///
@@ -159,33 +159,33 @@ internal class TestPlatformInstrumentationEvents
///
- /// The session finalization request start event id.
+ /// The session attachments processing request start event id.
///
@@ -159,33 +159,33 @@ internal class TestPlatformInstrumentationEvents
///
- /// The session finalization request stop event id.
+ /// The session attachments processing request stop event id.
///
@@ -159,33 +159,33 @@ internal class TestPlatformInstrumentationEvents
///
- /// Events fired on session finalization start of translation layer.
+ /// Events fired on session attachments processing start of translation layer.
///
@@ -159,33 +159,33 @@ internal class TestPlatformInstrumentationEvents
///
- /// Events fired on session finalization complete in translation layer.
+ /// Events fired on session attachments processing complete in translation layer.
///
diff --git a/src/Microsoft.TestPlatform.CrossPlatEngine/MultiTestRunFinalization/MultiTestRunFinalizationManager.cs b/src/Microsoft.TestPlatform.CrossPlatEngine/AttachmentsProcessing/TestRunAttachmentsProcessingManager.cs
similarity index 56%
rename from src/Microsoft.TestPlatform.CrossPlatEngine/MultiTestRunFinalization/MultiTestRunFinalizationManager.cs
rename to src/Microsoft.TestPlatform.CrossPlatEngine/AttachmentsProcessing/TestRunAttachmentsProcessingManager.cs
index d98e034d5c..6eff75838a 100644
--- a/src/Microsoft.TestPlatform.CrossPlatEngine/MultiTestRunFinalization/MultiTestRunFinalizationManager.cs
+++ b/src/Microsoft.TestPlatform.CrossPlatEngine/AttachmentsProcessing/TestRunAttachmentsProcessingManager.cs
@@ -16,48 +16,48 @@
using Microsoft.VisualStudio.TestPlatform.ObjectModel.Engine;
using Microsoft.VisualStudio.TestPlatform.ObjectModel.Logging;
-namespace Microsoft.VisualStudio.TestPlatform.CrossPlatEngine.MultiTestRunFinalization
+namespace Microsoft.VisualStudio.TestPlatform.CrossPlatEngine.TestRunAttachmentsProcessing
{
///
/// Orchestrates multi test run finalization operations.
///
- public class MultiTestRunFinalizationManager : IMultiTestRunFinalizationManager
+ public class TestRunAttachmentsProcessingManager : ITestRunAttachmentsProcessingManager
{
- private static string FinalizationCompleted = "Completed";
- private static string FinalizationCanceled = "Canceled";
- private static string FinalizationFailed = "Failed";
+ private static string AttachmentsProcessingCompleted = "Completed";
+ private static string AttachmentsProcessingCanceled = "Canceled";
+ private static string AttachmentsProcessingFailed = "Failed";
private readonly ITestPlatformEventSource testPlatformEventSource;
private readonly IDataCollectorAttachmentProcessor[] dataCollectorAttachmentsProcessors;
///
- /// Initializes a new instance of the class.
+ /// Initializes a new instance of the class.
///
- public MultiTestRunFinalizationManager(ITestPlatformEventSource testPlatformEventSource, params IDataCollectorAttachmentProcessor[] dataCollectorAttachmentsProcessors)
+ public TestRunAttachmentsProcessingManager(ITestPlatformEventSource testPlatformEventSource, params IDataCollectorAttachmentProcessor[] dataCollectorAttachmentsProcessors)
{
this.testPlatformEventSource = testPlatformEventSource ?? throw new ArgumentNullException(nameof(testPlatformEventSource));
this.dataCollectorAttachmentsProcessors = dataCollectorAttachmentsProcessors ?? throw new ArgumentNullException(nameof(dataCollectorAttachmentsProcessors));
}
///
- public async Task FinalizeMultiTestRunAsync(IRequestData requestData, IEnumerable attachments, IMultiTestRunFinalizationEventsHandler eventHandler, CancellationToken cancellationToken)
+ public async Task ProcessTestRunAttachmentsAsync(IRequestData requestData, IEnumerable attachments, ITestRunAttachmentsProcessingEventsHandler eventHandler, CancellationToken cancellationToken)
{
- await InternalFinalizeMultiTestRunAsync(requestData, new Collection(attachments.ToList()), eventHandler, cancellationToken).ConfigureAwait(false);
+ await InternalProcessTestRunAttachmentsAsync(requestData, new Collection(attachments.ToList()), eventHandler, cancellationToken).ConfigureAwait(false);
}
///
- public Task> FinalizeMultiTestRunAsync(IRequestData requestData, IEnumerable attachments, CancellationToken cancellationToken)
+ public Task> ProcessTestRunAttachmentsAsync(IRequestData requestData, IEnumerable attachments, CancellationToken cancellationToken)
{
- return InternalFinalizeMultiTestRunAsync(requestData, new Collection(attachments.ToList()), null, cancellationToken);
+ return InternalProcessTestRunAttachmentsAsync(requestData, new Collection(attachments.ToList()), null, cancellationToken);
}
- private async Task> InternalFinalizeMultiTestRunAsync(IRequestData requestData, Collection attachments, IMultiTestRunFinalizationEventsHandler eventHandler, CancellationToken cancellationToken)
+ private async Task> InternalProcessTestRunAttachmentsAsync(IRequestData requestData, Collection attachments, ITestRunAttachmentsProcessingEventsHandler eventHandler, CancellationToken cancellationToken)
{
Stopwatch stopwatch = Stopwatch.StartNew();
try
{
- testPlatformEventSource.MultiTestRunFinalizationStart(attachments?.Count ?? 0);
- requestData.MetricsCollection.Add(TelemetryDataConstants.NumberOfAttachmentsSentForFinalization, attachments?.Count ?? 0);
+ testPlatformEventSource.TestRunAttachmentsProcessingStart(attachments?.Count ?? 0);
+ requestData.MetricsCollection.Add(TelemetryDataConstants.NumberOfAttachmentsSentForProcessing, attachments?.Count ?? 0);
cancellationToken.ThrowIfCancellationRequested();
@@ -70,12 +70,12 @@ private async Task> InternalFinalizeMultiTestRunAsync(
if (completedTask == task)
{
- return FinalizeOperation(requestData, new MultiTestRunFinalizationCompleteEventArgs(false, null), await task, stopwatch, eventHandler);
+ return FinalizeOperation(requestData, new TestRunAttachmentsProcessingCompleteEventArgs(false, null), await task, stopwatch, eventHandler);
}
else
{
- eventHandler?.HandleLogMessage(TestMessageLevel.Informational, "Finalization was cancelled.");
- return FinalizeOperation(requestData, new MultiTestRunFinalizationCompleteEventArgs(true, null), attachments, stopwatch, eventHandler);
+ eventHandler?.HandleLogMessage(TestMessageLevel.Informational, "Attachments processing was cancelled.");
+ return FinalizeOperation(requestData, new TestRunAttachmentsProcessingCompleteEventArgs(true, null), attachments, stopwatch, eventHandler);
}
}
}
@@ -83,20 +83,20 @@ private async Task> InternalFinalizeMultiTestRunAsync(
{
if (EqtTrace.IsWarningEnabled)
{
- EqtTrace.Warning("MultiTestRunFinalizationManager: operation was cancelled.");
+ EqtTrace.Warning("TestRunAttachmentsProcessingManager: operation was cancelled.");
}
- return FinalizeOperation(requestData, new MultiTestRunFinalizationCompleteEventArgs(true, null), attachments, stopwatch, eventHandler);
+ return FinalizeOperation(requestData, new TestRunAttachmentsProcessingCompleteEventArgs(true, null), attachments, stopwatch, eventHandler);
}
catch (Exception e)
{
- EqtTrace.Error("MultiTestRunFinalizationManager: Exception in FinalizeMultiTestRunAsync: " + e);
+ EqtTrace.Error("TestRunAttachmentsProcessingManager: Exception in ProcessTestRunAttachmentsAsync: " + e);
eventHandler?.HandleLogMessage(TestMessageLevel.Error, e.Message);
- return FinalizeOperation(requestData, new MultiTestRunFinalizationCompleteEventArgs(false, e), attachments, stopwatch, eventHandler);
+ return FinalizeOperation(requestData, new TestRunAttachmentsProcessingCompleteEventArgs(false, e), attachments, stopwatch, eventHandler);
}
}
- private async Task> ProcessAttachmentsAsync(Collection attachments, IMultiTestRunFinalizationEventsHandler eventsHandler, CancellationToken cancellationToken)
+ private async Task> ProcessAttachmentsAsync(Collection attachments, ITestRunAttachmentsProcessingEventsHandler eventsHandler, CancellationToken cancellationToken)
{
if (attachments == null || !attachments.Any()) return attachments;
@@ -119,8 +119,8 @@ private async Task> ProcessAttachmentsAsync(Collection
}
IProgress progressReporter = new Progress((int progress) =>
- eventsHandler?.HandleMultiTestRunFinalizationProgress(
- new MultiTestRunFinalizationProgressEventArgs(attachmentsHandlerIndex, attachmentProcessorUris, progress, dataCollectorAttachmentsProcessors.Length)));
+ eventsHandler?.HandleTestRunAttachmentsProcessingProgress(
+ new TestRunAttachmentsProcessingProgressEventArgs(attachmentsHandlerIndex, attachmentProcessorUris, progress, dataCollectorAttachmentsProcessors.Length)));
ICollection processedAttachments = await dataCollectorAttachmentsProcessor.ProcessAttachmentSetsAsync(new Collection(attachmentsToBeProcessed), progressReporter, logger, cancellationToken).ConfigureAwait(false);
@@ -135,31 +135,31 @@ private async Task> ProcessAttachmentsAsync(Collection
return attachments;
}
- private Collection FinalizeOperation(IRequestData requestData, MultiTestRunFinalizationCompleteEventArgs completeArgs, Collection attachments, Stopwatch stopwatch, IMultiTestRunFinalizationEventsHandler eventHandler)
+ private Collection FinalizeOperation(IRequestData requestData, TestRunAttachmentsProcessingCompleteEventArgs completeArgs, Collection attachments, Stopwatch stopwatch, ITestRunAttachmentsProcessingEventsHandler eventHandler)
{
- testPlatformEventSource.MultiTestRunFinalizationStop(attachments.Count);
- requestData.MetricsCollection.Add(TelemetryDataConstants.NumberOfAttachmentsAfterFinalization, attachments.Count);
- requestData.MetricsCollection.Add(TelemetryDataConstants.FinalizationState, completeArgs.Error != null ? FinalizationFailed : completeArgs.IsCanceled ? FinalizationCanceled : FinalizationCompleted);
+ testPlatformEventSource.TestRunAttachmentsProcessingStop(attachments.Count);
+ requestData.MetricsCollection.Add(TelemetryDataConstants.NumberOfAttachmentsAfterProcessing, attachments.Count);
+ requestData.MetricsCollection.Add(TelemetryDataConstants.AttachmentsProcessingState, completeArgs.Error != null ? AttachmentsProcessingFailed : completeArgs.IsCanceled ? AttachmentsProcessingCanceled : AttachmentsProcessingCompleted);
stopwatch.Stop();
- requestData.MetricsCollection.Add(TelemetryDataConstants.TimeTakenInSecForFinalization, stopwatch.Elapsed.TotalSeconds);
+ requestData.MetricsCollection.Add(TelemetryDataConstants.TimeTakenInSecForAttachmentsProcessing, stopwatch.Elapsed.TotalSeconds);
completeArgs.Metrics = requestData.MetricsCollection.Metrics;
- eventHandler?.HandleMultiTestRunFinalizationComplete(completeArgs, attachments);
+ eventHandler?.HandleTestRunAttachmentsProcessingComplete(completeArgs, attachments);
return attachments;
}
- private IMessageLogger CreateMessageLogger(IMultiTestRunFinalizationEventsHandler eventsHandler)
+ private IMessageLogger CreateMessageLogger(ITestRunAttachmentsProcessingEventsHandler eventsHandler)
{
- return eventsHandler != null ? (IMessageLogger)new FinalizationMessageLogger(eventsHandler) : new NullMessageLogger();
+ return eventsHandler != null ? (IMessageLogger)new AttachmentsProcessingMessageLogger(eventsHandler) : new NullMessageLogger();
}
- private class FinalizationMessageLogger : IMessageLogger
+ private class AttachmentsProcessingMessageLogger : IMessageLogger
{
- private readonly IMultiTestRunFinalizationEventsHandler eventsHandler;
+ private readonly ITestRunAttachmentsProcessingEventsHandler eventsHandler;
- public FinalizationMessageLogger(IMultiTestRunFinalizationEventsHandler eventsHandler)
+ public AttachmentsProcessingMessageLogger(ITestRunAttachmentsProcessingEventsHandler eventsHandler)
{
this.eventsHandler = eventsHandler ?? throw new ArgumentNullException(nameof(eventsHandler));
}
@@ -16,48 +16,48 @@
{
///
- /// Orchestrates multi test run finalization operations.
+ /// Orchestrates test run attachments processing operations.
///
diff --git a/src/Microsoft.TestPlatform.ObjectModel/Client/Events/MultiTestRunFinalizationCompleteEventArgs.cs b/src/Microsoft.TestPlatform.ObjectModel/Client/Events/TestRunAttachmentsProcessingCompleteEventArgs.cs
similarity index 65%
rename from src/Microsoft.TestPlatform.ObjectModel/Client/Events/MultiTestRunFinalizationCompleteEventArgs.cs
rename to src/Microsoft.TestPlatform.ObjectModel/Client/Events/TestRunAttachmentsProcessingCompleteEventArgs.cs
index 0ca669e6a1..b5e446ff68 100644
--- a/src/Microsoft.TestPlatform.ObjectModel/Client/Events/MultiTestRunFinalizationCompleteEventArgs.cs
+++ b/src/Microsoft.TestPlatform.ObjectModel/Client/Events/TestRunAttachmentsProcessingCompleteEventArgs.cs
@@ -8,27 +8,27 @@ namespace Microsoft.VisualStudio.TestPlatform.ObjectModel.Client
using System.Runtime.Serialization;
[DataContract]
- public class MultiTestRunFinalizationCompleteEventArgs : EventArgs
+ public class TestRunAttachmentsProcessingCompleteEventArgs : EventArgs
{
///
/// Default constructor.
///
- /// Specifies whether the finalization is canceled.
- /// Specifies the error encountered during the execution of the finalization.
- public MultiTestRunFinalizationCompleteEventArgs(bool isCanceled, Exception error)
+ /// Specifies whether the attachments processing is canceled.
+ /// Specifies the error encountered during the execution of the attachments processing.
+ public TestRunAttachmentsProcessingCompleteEventArgs(bool isCanceled, Exception error)
{
this.IsCanceled = isCanceled;
this.Error = error;
}
///
/// Gets a value indicating whether the finalization is canceled or not.
///
[DataMember]
public bool IsCanceled { get; private set; }
///
/// Gets the error encountered during the finalization of the test runs. Null if there is no error.
///
[DataMember]
public Exception Error { get; private set; }
@@ -8,27 +8,27 @@ namespace Microsoft.VisualStudio.TestPlatform.ObjectModel.Client
}
///
- /// Gets a value indicating whether the finalization is canceled or not.
+ /// Gets a value indicating whether the attachments processing is canceled or not.
///
[DataMember]
@@ -8,27 +8,27 @@ namespace Microsoft.VisualStudio.TestPlatform.ObjectModel.Client
public bool IsCanceled { get; private set; }
///
- /// Gets the error encountered during the finalization of the test runs. Null if there is no error.
+ /// Gets the error encountered during the attachments processing of the test runs. Null if there is no error.
///
[DataMember]
diff --git a/src/Microsoft.TestPlatform.ObjectModel/Client/Payloads/MultiTestRunFinalizationPayload.cs b/src/Microsoft.TestPlatform.ObjectModel/Client/Payloads/TestRunAttachmentsProcessingPayload.cs
similarity index 79%
rename from src/Microsoft.TestPlatform.ObjectModel/Client/Payloads/MultiTestRunFinalizationPayload.cs
rename to src/Microsoft.TestPlatform.ObjectModel/Client/Payloads/TestRunAttachmentsProcessingPayload.cs
index 844b86e8dc..6abdb68082 100644
--- a/src/Microsoft.TestPlatform.ObjectModel/Client/Payloads/MultiTestRunFinalizationPayload.cs
+++ b/src/Microsoft.TestPlatform.ObjectModel/Client/Payloads/TestRunAttachmentsProcessingPayload.cs
@@ -7,9 +7,9 @@ namespace Microsoft.VisualStudio.TestPlatform.ObjectModel.Client
using System.Runtime.Serialization;
///
/// Class used to define the MultiTestRunFinalizationPayload sent by the Vstest.console translation layers into design mode
///
- public class MultiTestRunFinalizationPayload
+ public class TestRunAttachmentsProcessingPayload
{
///
/// Collection of attachments.
@@ -7,9 +7,9 @@ namespace Microsoft.VisualStudio.TestPlatform.ObjectModel.Client
using System.Runtime.Serialization;
///
- /// Class used to define the MultiTestRunFinalizationPayload sent by the Vstest.console translation layers into design mode
+ /// Class used to define the TestRunAttachmentsProcessingPayload sent by the Vstest.console translation layers into design mode
///
diff --git a/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/Resources.Designer.cs b/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/Resources.Designer.cs
index d20d874ef0..a218efe7f5 100644
--- a/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/Resources.Designer.cs
+++ b/src/Microsoft.TestPlatform.VsTestConsole.TranslationLayer/Resources/Resources.Designer.cs
@@ -62,11 +62,11 @@ internal Resources() {
}
///
/// Looks up a localized string similar to The active Multi Test Runs Finalization was aborted..
///
- public static string AbortedMultiTestRunFinalization {
+ public static string AbortedTestRunAttachmentsProcessing {
get {
- return ResourceManager.GetString("AbortedMultiTestRunFinalization", resourceCulture);
+ return ResourceManager.GetString("AbortedTestRunAttachmentsProcessing", resourceCulture);
}
}
@@ -62,11 +62,11 @@ internal Resources() {
}
///
- /// Looks up a localized string similar to The active Multi Test Runs Finalization was aborted..
+ /// Looks up a localized string similar to The active Test Run Attachments Processing was aborted..
///